@@ -13,12 +13,6 @@ from fuzzywuzzy.string_processing import StringProcessor
 if sys.version_info[0] == 3:
     unicode = str
 
-if sys.version_info[:2] == (2, 6):
-    # Monkeypatch to make tests work on 2.6
-    def assertLess(first, second, msg=None):
-        assert first > second
-    unittest.TestCase.assertLess = assertLess
-
 
 class StringProcessingTest(unittest.TestCase):
     def test_replace_non_letters_non_numbers_with_whitespace(self):
@@ -90,6 +84,13 @@ class RatioTest(unittest.TestCase):
         self.s5 = "atlanta braves vs new york mets"
         self.s6 = "new york mets - atlanta braves"
         self.s7 = 'new york city mets - atlanta braves'
+        # test silly corner cases
+        self.s8 = '{'
+        self.s8a = '{'
+        self.s9 = '{a'
+        self.s9a = '{a'
+        self.s10 = 'a{'
+        self.s10a = '{b'
 
         self.cirque_strings = [
             "cirque du soleil - zarkana - las vegas",
@@ -112,6 +113,8 @@ class RatioTest(unittest.TestCase):
 
     def testEqual(self):
         self.assertEqual(fuzz.ratio(self.s1, self.s1a), 100)
+        self.assertEqual(fuzz.ratio(self.s8, self.s8a), 100)
+        self.assertEqual(fuzz.ratio(self.s9, self.s9a), 100)
 
     def testCaseInsensitive(self):
         self.assertNotEqual(fuzz.ratio(self.s1, self.s2), 100)
@@ -126,9 +129,17 @@ class RatioTest(unittest.TestCase):
     def testPartialTokenSortRatio(self):
         self.assertEqual(fuzz.partial_token_sort_ratio(self.s1, self.s1a), 100)
         self.assertEqual(fuzz.partial_token_sort_ratio(self.s4, self.s5), 100)
+        self.assertEqual(fuzz.partial_token_sort_ratio(self.s8, self.s8a, full_process=False), 100)
+        self.assertEqual(fuzz.partial_token_sort_ratio(self.s9, self.s9a, full_process=True), 100)
+        self.assertEqual(fuzz.partial_token_sort_ratio(self.s9, self.s9a, full_process=False), 100)
+        self.assertEqual(fuzz.partial_token_sort_ratio(self.s10, self.s10a, full_process=False), 50)
 
     def testTokenSetRatio(self):
         self.assertEqual(fuzz.token_set_ratio(self.s4, self.s5), 100)
+        self.assertEqual(fuzz.token_set_ratio(self.s8, self.s8a, full_process=False), 100)
+        self.assertEqual(fuzz.token_set_ratio(self.s9, self.s9a, full_process=True), 100)
+        self.assertEqual(fuzz.token_set_ratio(self.s9, self.s9a, full_process=False), 100)
+        self.assertEqual(fuzz.token_set_ratio(self.s10, self.s10a, full_process=False), 50)
 
     def testPartialTokenSetRatio(self):
         self.assertEqual(fuzz.partial_token_set_ratio(self.s4, self.s7), 100)
@@ -162,9 +173,9 @@ class RatioTest(unittest.TestCase):
     def testQRatioUnicode(self):
         self.assertEqual(fuzz.WRatio(unicode(self.s1), unicode(self.s1a)), 100)
 
-    def testEmptyStringsScore0(self):
-        self.assertEqual(fuzz.ratio("", ""), 0)
-        self.assertEqual(fuzz.partial_ratio("", ""), 0)
+    def testEmptyStringsScore100(self):
+        self.assertEqual(fuzz.ratio("", ""), 100)
+        self.assertEqual(fuzz.partial_ratio("", ""), 100)
 
     def testIssueSeven(self):
         s1 = "HSINCHUANG"
